# LocalAuthUpstreamConfig

Local authentication upstream identity providers for example an Agilicus Agent running onsite.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**upstream_id** | **str** | Uniquely identifies the upstream resource providing the local authentication for instance an Agilicus Agent Connector ID. | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


